Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(21)

Unified Diff: ash/system/overview/overview_button_tray.h

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/system/overview/overview_button_tray.h
diff --git a/ash/system/overview/overview_button_tray.h b/ash/system/overview/overview_button_tray.h
index ba45fb9b60678700c15767535d03105acdbb134d..18563f321af3f997fa8a4e95c18cec6dbffaaabd 100644
--- a/ash/system/overview/overview_button_tray.h
+++ b/ash/system/overview/overview_button_tray.h
@@ -30,7 +30,7 @@ class ASH_EXPORT OverviewButtonTray : public TrayBackgroundView,
~OverviewButtonTray() override;
// Updates the tray's visibility based on the LoginStatus and the current
// state of MaximizeMode
virtual void UpdateAfterLoginStatusChange(LoginStatus status);
// ActionableView:
@@ -40,8 +40,8 @@ class ASH_EXPORT OverviewButtonTray : public TrayBackgroundView,
void OnSessionStateChanged(session_manager::SessionState state) override;
// ShellObserver:
- void OnMaximizeModeStarted() override;
- void OnMaximizeModeEnded() override;
+ void OnTabletModeStarted() override;
+ void OnTabletModeEnded() override;
void OnOverviewModeStarting() override;
void OnOverviewModeEnded() override;
@@ -53,7 +53,7 @@ class ASH_EXPORT OverviewButtonTray : public TrayBackgroundView,
private:
friend class OverviewButtonTrayTest;
// Sets the icon to visible if maximize mode is enabled and
// WindowSelectorController::CanSelect.
void UpdateIconVisibility();
@@ -30,7 +30,7 @@ class ASH_EXPORT OverviewButtonTray : public TrayBackgroundView,
~OverviewButtonTray() override;
// Updates the tray's visibility based on the LoginStatus and the current
- // state of MaximizeMode
+ // state of TabletMode
virtual void UpdateAfterLoginStatusChange(LoginStatus status);
// ActionableView:
@@ -53,7 +53,7 @@ class ASH_EXPORT OverviewButtonTray : public TrayBackgroundView,
private:
friend class OverviewButtonTrayTest;
- // Sets the icon to visible if maximize mode is enabled and
+ // Sets the icon to visible if tablet mode is enabled and
// WindowSelectorController::CanSelect.
void UpdateIconVisibility();

Powered by Google App Engine
This is Rietveld 408576698